@@ -33,7 +33,7 @@ const sessionID =
 try {
   var sattelanalyse = new WebSocket(`${ws}/apps/${app}`, ["soap", "wamp"]);
 } catch (error) {
-  PrintLog([error]);
+  getError(error)
 }
 var onsqlresult = null;
 //var load_num;
@@ -123,7 +123,7 @@ sattelanalyse.onmessage = (e) => {
     try {
       onsqlresult(data.rows);
     } catch (error) {
-      console.log(error);
+      getError(error)
     }
   }
   if (data.wsevent === "sda_int3") {
@@ -174,16 +174,37 @@ sattelanalyse.onmessage = (e) => {
 };
 
 
+/**
+ * The function `open_img` opens a modal window to display an image.
+ * @param params - The `params` parameter is used to specify the ID of the image that you want to open
+ * in the modal.
+ */
 function open_img(params) {
   UIkit.modal($(`#modal-center-load${params}`)).show();
 }
 
+/**
+ * The load function sends a request to retrieve a recording with a specific ID and parameters, and
+ * logs the request if the log variable is true.
+ * @param params - The `params` parameter is a string that contains additional information or
+ * instructions for the `load` function. It is used as part of the message sent to the `sattelanalyse`
+ * object.
+ * @param id - The `id` parameter is used to specify the identifier of the recording that needs to be
+ * retrieved.
+ */
 function load(params, id) {
   sattelanalyse.send(`recording retrieve ${id} ${params}`);
   if (log) {
     console.log("load", `recording retrieve ${id} ${params}`);
   }
 }
+
+/**
+ * The function `openDelDialog` opens a dialog box with a warning message and options to delete an
+ * image or cancel the operation.
+ * @param params - The `params` parameter is an object that contains the information about the image to
+ * be deleted. It is passed as an argument to the `openDelDialog` function.
+ */
 function openDelDialog(params) {
   DelImg = params;
   OpenModDialog({
@@ -195,6 +216,10 @@ function openDelDialog(params) {
   });
 }
 
+/**
+ * The function `del_img()` sends a SQL query to delete a record from the "recordings" table, logs the
+ * query if a variable `log` is true, and then reloads the current page.
+ */
 function del_img() {
   sattelanalyse.send(`sql DELETE FROM recordings WHERE recording_id=${DelImg}`);
   if (log) {
@@ -206,6 +231,11 @@ function del_img() {
   location.reload();
 }
 
+/**
+ * The function `result_1` updates the content of specific HTML elements with values from the `params`
+ * object.
+ * @param params - The `params` object contains the following properties:
+ */
 function result_1(params) {
   if (log) console.log("result_1", params);
   document.getElementById("S1").innerHTML = params.product;
@@ -220,6 +250,11 @@ function result_1(params) {
       }` || "";
   document.getElementById("N1").innerHTML = params.notes;
 }
+
+/**
+ * The function "result_2" updates the HTML elements with the values from the "params" object.
+ * @param params - The `params` object contains the following properties:
+ */
 function result_2(params) {
   if (log) console.log("result_2", params);
   document.getElementById("S2").innerHTML = params.product;
@@ -236,6 +271,11 @@ function result_2(params) {
 }
 
 
+/**
+ * The function `RowImg` is used to dynamically create and display rows of images on a webpage.
+ * @param params - The `params` parameter is an array of objects. Each object in the array represents a
+ * row of data and contains the following properties:
+ */
 function RowImg(params) {
   fi = 0;
   recID = [];
@@ -309,10 +349,15 @@ var max=0;
 
 var SetMax=false;
 var newMax=0
-  function setMax(params) {
-    SetMax = true
-    newMax = params
-  }
+
+/**
+ * The function "setMax" sets a variable "newMax" to the value of the parameter passed in.
+ * @param params - The `params` parameter is a value that will be assigned to the `newMax` variable.
+ */
+function setMax(params) {
+  SetMax = true
+  newMax = params
+}
 
   var dom = document.getElementById('chart-container');
   var myChartX = echarts.init(dom, 'dark', {
@@ -321,6 +366,13 @@ var newMax=0
   });
 
 var open_chartID;
+
+/**
+ * The function `OpenChart` opens a chart modal and sends a SQL query to retrieve pressure values for a
+ * specific recording ID.
+ * @param id - The `id` parameter is the identifier of the chart that you want to open. It is used to
+ * retrieve the pressure values from the database for that specific chart.
+ */
 function OpenChart(id) {
     open_chartID = id
     onsqlresult = heatchart
@@ -328,6 +380,9 @@ function OpenChart(id) {
     UIkit.modal('#chart_modal').show();
 }
 
+/**
+ * The function `PDFgenGal` generates a PDF document containing a gallery of images.
+ */
 function PDFgenGal(){
     let name = localStorage.getItem('client_name').split(' ')
 
@@ -419,6 +474,12 @@ var data2D = new Array(numRows);
 var Cdata;
 var  tmp;
 
+/**
+ * The `heatchart` function generates a 3D bar chart using the provided data and displays it on a
+ * webpage.
+ * @param data - The `data` parameter is an array of objects. Each object represents a data point and
+ * has the following properties:
+ */
 function heatchart (data){
     let saddle = JSON.parse(recData[open_chartID])
     data.forEach(e=> {
@@ -565,6 +626,12 @@ function heatchart (data){
     window.addEventListener('resize', myChartX.resize);
 }
 
+/**
+ * The function `setChartType` sets the type of chart to be displayed in a charting library and updates
+ * the chart with the new type.
+ * @param params - The `params` parameter is the type of chart that you want to set. It can be one of
+ * the following values:
+ */
 function setChartType(params) {
 
     myChartX.setOption((option = {
@@ -613,7 +680,7 @@ function ClientInfo(params) {
    * @param {string}name - The name of the client
    * @param {string}mail - The email address of the user.
    */
-  function info(client_id,name,mail,fc) {
+  function info(client_id,name,fname,lname,mail,fc) {
     onsqlresult = ClientInfo
     sattelanalyse.send(`sql select * from sessions where client_id=${client_id}`);
     let inter = setInterval(()=> {
@@ -621,6 +688,8 @@ function ClientInfo(params) {
         localStorage.setItem('client_name',name)
         localStorage.setItem('client_mail',mail)
         localStorage.setItem('client_id',client_id)
+        localStorage.setItem('client_forenames',fname)
+        localStorage.setItem('client_surename',lname)
         location.href = "/production/client.tcls"
         clearInterval(inter);
       }, 500);
