@@ -63,6 +63,16 @@ document.getElementById('headliner').innerHTML = localStorage.getItem('client_na
 
 // document.getElementById('product1').setAttribute('placeholder',gettrans('sda_marke'))
 
+/**
+ * The function sets the contrast value based on the user's input and saves it in local storage.
+ */
+function setContrast () {
+  setting.vertical = $('#vertical').val();
+  console.log(setting.vertical);
+  localStorage.setItem("setting",JSON.stringify(setting));
+  sattelanalyse.send(`set clientsettings ${JSON.stringify(setting)}`)
+}
+
 /**
  * It sets the pelvis size.
  */
@@ -255,7 +265,7 @@ function getHockerNr(num){
   sitzknochen = new WebSocket(`ws://smartcube${num}.local/messages`,["soap","wamp"]);
   run_Sitzknochen(num);
   } catch (error) {
-   console.error(error);
+    getError(error)
   }
 }
 
@@ -391,7 +401,7 @@ function run_Sitzknochen(num) {
       try {
         sitz_data = JSON.parse(e.data);
       } catch (error) {
-        console.error(error);
+        getError(error)
       }
 
       if(sitz_data.wsevent === "plugged"){
@@ -412,34 +422,21 @@ function run_Sitzknochen(num) {
 
     }
     sitzknochen.onerror= (e)=>{
-      console.error(e);
+      getError(e)
     }
 }
 
-/**
- * If the user tries to leave the page, ask them if they're sure they want to leave.
- * @param event - The event object.
- * @returns The return value of the function is the string "Are you sure you want to leave the page?"
- */
-//const onConfirmRefresh = function (event) {
-//  event.preventDefault();
-//  if(event.returnValue == true)
-//  console.log(event);
 
-//  return event.returnValue = true;
-//  //sattelanalyse.send('btdisconnect')
-
-//}
 
 /* Adding an event listener to the window object. The event listener is listening for the beforeunload
 event. When the event is triggered, the onConfirmRefresh function is called. */
 //window.addEventListener("beforeunload", onConfirmRefresh, { capture: true });
 
 /* The above code is a JavaScript code that is binding two events to the window object. */
-$( window ).bind( 'beforeunload' , function( event ) {
+$( window ).bind( 'beforeunload' , ( event ) => {
   event.preventDefault();
   return '';
-} ).bind( 'unload', function( event ) {
+} ).bind( 'unload', ( event ) => {
   sattelanalyse.send('btdisconnect')
 } );
 /**
@@ -453,6 +450,7 @@ function run_Sattelanalyse() {
       rec_cancel(1);
       rec_cancel(2);
       sattelanalyse.send('get clientsettings')
+      grid_socet('no')
       if(localStorage.getItem('session').split(' ')[0]=='restart'){
         sess = localStorage.getItem('session').split(' ')[1]
       }
@@ -470,7 +468,7 @@ function run_Sattelanalyse() {
         try {
            data = JSON.parse(e.data);
         } catch (error) {
-          console.error(error);
+          getError(error)
         }
         if(data.wsevent ==="clientsettings"){
           setting = data.clientsettings
@@ -725,12 +723,12 @@ function run_Sattelanalyse() {
           try {
           onsqlresult (data.rows);
           } catch (error) {
-            //console.log(error);
+            getError(error)
           }
         }
     }
-    sattelanalyse.onerror = (error) => {
-      console.error(`[error] ${error.message}`);
+    sattelanalyse.onerror = (e) => {
+      getError(e)
     };
 }
 
@@ -837,6 +835,9 @@ function error_msg (jsn){
   if(jsn.wsevent){
     txt += `<p>WSEVENT: ${jsn.wsevent}</p>`
   }
+  if(jsn.class == 'disconnected'){
+    txt_num = 'err_bt_discon';
+  }
 
   if(jsn.class){
     txt += `<p>CLASS: ${jsn.class}</p>`
@@ -860,9 +861,16 @@ function error_msg (jsn){
     txt_num ='err_num_1';
     OpenModDialog({type:'warn',title:[txt_num],msg:txt,master_btn:['button_ok']})
   }
-  if(jsn.nr != 1 && jsn.nr != 3){
-    txt_num ='err_num_2';
-    OpenModDialog({type:'error',title:[txt_num],msg:txt,master_btn:['button_ok']})
+  if(jsn.nr == 5){
+    txt_num = 'err_num_5';
+    OpenModDialog({type:'warn',title:[txt_num],msg:txt,master_btn:['button_ok']})
+  }
+  if(jsn.nr != 1 && jsn.nr != 3 && jsn.nr != 5){
+    if(txt.includes("doesn't exist")){
+      OpenModDialog({type:'error',title:"doesn't exist",msg:txt,master_btn:['button_ok','LinkTo("clients.tcls")']})
+    } else{
+      OpenModDialog({type:'error',title:[txt_num],msg:txt,master_btn:['button_ok']})
+    }
   }
 }
 /**
@@ -1329,6 +1337,7 @@ function grid_socet(type){
  * @param num - 0-7
  */
 function set_contrast(num){
+  setContrast();
   // console.log(`set jpeg colorcontrast ${num}`);
   sattelanalyse.send(`set jpeg colorcontrast ${num}`);
 }
@@ -1715,6 +1724,9 @@ function getLog(params){
  * @param params - an array of objects, each object has a recording_id property
  */
 function RowImg(params) {
+  if(params.length == 0){
+    document.getElementById('ZeroImage').classList.remove('hidden')
+  }
   fi = 0;
   recID = [];
   onsqlresult = getLog;
@@ -1867,7 +1879,7 @@ function ClientInfo(params) {
  * @param {string}name - The name of the client
  * @param {string}mail - The email address of the user.
  */
-function info(client_id,name,mail,fc) {
+function info(client_id,name,fname,lname,mail,fc) {
   onsqlresult = ClientInfo
   sattelanalyse.send(`sql select * from sessions where client_id=${client_id}`);
   let inter = setInterval(()=> {
@@ -1875,7 +1887,8 @@ function info(client_id,name,mail,fc) {
       localStorage.setItem('client_name',name)
       localStorage.setItem('client_mail',mail)
       localStorage.setItem('client_id',client_id)
-
+      localStorage.setItem('client_forenames',fname)
+      localStorage.setItem('client_surename',lname)
       location.href = "/production/client.tcls"
 
       clearInterval(inter);
@@ -2006,4 +2019,4 @@ function setProduct2(params) {
 //    gif.addFrame(imggif);
 //    currentFrame++;
 //  }, 1000 / frameRate)
-//}
+//}
\ No newline at end of file
