@@ -21,11 +21,22 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
     Created on : 04.06.2021, 21:08:29
     Author     : Peter Bauer
 */
+
+if(localStorage.getItem('force') === 'false'){
+  console.log('force reload');
+  localStorage.setItem('force',true)
+  //let inter = setInterval( () => {
+     location.reload(true)
+    // clearInterval(inter);
+  //}, 500)
+}
+
 var aLangKeys = new Object();
-var lang;
+var lang = "";
 var back = document.getElementsByClassName('right_col')[0];
 let menu_bread = document.getElementById('menu_bread');
 var log = localStorage.getItem('log') || false;
+var cardsReady = false
 
 var week = ["week_0","week_1","week_2","week_3","week_4","week_5","week_6"];
 var month = ["mon_0","mon_1","mon_2","mon_3","mon_4","mon_5","mon_6","mon_7","mon_8","mon_9","mon_10","mon_11"];
@@ -33,15 +44,116 @@ var month = ["mon_0","mon_1","mon_2","mon_3","mon_4","mon_5","mon_6","mon_7","mo
 var httpSetconfig = new XMLHttpRequest();
 var httpreboot = new XMLHttpRequest();
 
+const script_host = location.origin;
+const script_ws = script_host.replace('http','ws');
+
+const script_apps= "satteldruckanalyse";
+const script_websocket = new WebSocket(`${script_ws}/apps/${script_apps}`, ["soap", "wamp"]);
+
+var script_Data= new Object();
+var script_setting = new Object();
+
+var URL_SmartCube = ""
+
+var htdocsInfo = new Object();
+
+script_websocket.onopen = (e)=>{
+  console.log('websocket open');
+  script_websocket.send('get clientsettings')
+}
+
+script_websocket.onmessage = (e)=> {
+  try {
+    script_Data = JSON.parse(e.data);
+  } catch (error) {
+    getError(error)
+  }
+
+  if(script_Data.wsevent ==="clientsettings"){
+    script_setting = script_Data.clientsettings
+    console.log(script_setting);
+    if(script_setting.bg){
+      back.removeAttribute('class')
+      back.classList.add('right_col')
+      back.classList.add(script_setting.bg)
+    }
+    if(script_setting.smartcube){
+      if(document.getElementById('url_smartcube')){
+        document.getElementById('url_smartcube').value = script_setting.smartcube
+        localStorage.setItem('smartcube',script_setting.smartcube)
+      }
+    }
+    try {
+      if(script_setting.UserCompany){
+        document.getElementById('Company_sidenav').innerHTML = script_setting.UserCompany
+        if(document.getElementById('system_user_company')) {
+          document.getElementById('system_user_company').value = script_setting.UserCompany
+        }
+      } else {
+        document.getElementById('Company_sidenav').innerHTML = "Velometrik®"
+      }
+    } catch (error) {
+      getError(error)
+    }
+
+    try {
+      if(script_setting.UserName){
+        document.getElementById('User_sidenav').innerHTML = script_setting.UserName
+        if(document.getElementById('system_user_name'))
+        document.getElementById('system_user_name').value = script_setting.UserName
+      }
+      if(script_setting.UserCity){
+        if(document.getElementById('system_user_city'))
+        document.getElementById('system_user_city').value = script_setting.UserCity
+      }
+      if(script_setting.UserStreet){
+        if(document.getElementById('system_user_street'))
+        document.getElementById('system_user_street').value = script_setting.UserStreet
+      }
+      if(script_setting.UserPhone){
+        if(document.getElementById('system_user_phone'))
+        document.getElementById('system_user_phone').value = script_setting.UserPhone
+      }
+      if(script_setting.UserWeb){
+        if(document.getElementById('system_user_web'))
+        document.getElementById('system_user_web').value = script_setting.UserWeb
+      }
+      if(script_setting.UserMail){
+        if(document.getElementById('system_user_mail'))
+        document.getElementById('system_user_mail').value = script_setting.UserMail
+      }
+      if(script_setting.LoginMail){
+        if(document.getElementById('system_login_mail'))
+        document.getElementById('system_login_mail').value = script_setting.LoginMail
+      }
+      if(script_setting.LoginPass){
+        if(document.getElementById('system_login_pass'))
+        document.getElementById('system_login_pass').value = script_setting.LoginPass
+      }
+      if(script_setting.UserEinleitung && script_setting.UserEinleitung !== ""){
+        if(document.getElementById('system_user_einleitung'))
+        document.getElementById('system_user_einleitung').value = script_setting.UserEinleitung
+      }
+    } catch (error) {
+      getError(error)
+    }
+
+  }
+
+}
+script_websocket.onerror= (e)=>{
+  if(location.pathname === '/production/dashboard.tcls'){
+    return;
+  }
+  getError(e)
+  console.error(e);
+}
+
+
 
 var devLangKeys = localStorage.getItem('devLang') ? JSON.parse(localStorage.getItem('devLang')) : new Object();
 
 
-if(localStorage.getItem('right_col')){
-  back.classList.add(localStorage.getItem('right_col'));
-} else{
-  back.classList.add(`img_0`)
-}
 /**
  * It takes a JSON object as a parameter, then loops through all the elements with the attribute "key"
  * and replaces the innerHTML with the value of the key attribute in the JSON object
@@ -50,35 +162,42 @@ if(localStorage.getItem('right_col')){
  function _Translate(params) {
   console.log('init translatejs');
   aLangKeys = params
-  // console.log(params)
       if(localStorage.getItem('lang')){
           lang = localStorage.getItem('lang')
-          // console.log(localStorage.getItem('lang'));
         }
+  if(document.getElementById('lang_list')){
   let lang_list = document.getElementById('lang_list');
-  // let lang_list_2 = document.getElementById('lang_list_2');
-  // lang_list_2.innerHTML="";
   lang_list.innerHTML="";
+  
   let zusatzlang = params.zusatzlang;
   let primarylang = params.lang;
-  let li_pl = document.createElement('li');
-  let div_pl = document.createElement('div');
-  div_pl.classList.add('col-md-3', 'col-sm-12', 'form-group')
-  div_pl.innerHTML = `<a href="#" onclick="langSelected('${primarylang.split(' ')[0]}_${primarylang.split(' ')[0]}.UTF-8');"><img class="sprachwahl" src="images/${primarylang.split(' ')[0]}.png"> ${primarylang.split(' ')[1]}</a>`
-  li_pl.setAttribute('style','float: none;width: 100%;margin-bottom: 10px;')
-  li_pl.innerHTML = `<a style="justify-content: space-between;" href="#select" onclick="langSelected('${primarylang.split(' ')[0]}_${primarylang.split(' ')[0]}.UTF-8');"><img class="sprachwahl_klein" src="images/${primarylang.split(' ')[0]}.png">${primarylang.split(' ')[1]}</a>`
-  lang_list.prepend(li_pl)
+  //let li_pl = document.createElement('div');
+  let lang_card = newElement({element:'div',cls:['uk-card','uk-card-default','cur_pointer','lang-card'],attr:[['onclick',`langSelected('${primarylang.split(' ')[0]}_${primarylang.split(' ')[0]}.UTF-8')`]]},lang_list)
+  let lang_head = newElement({element:'div',cls:['uk-card-header','flex-column-center']},lang_card)
+  let lang_img  = newElement({element:'img',cls:['sprachwahl'],attr:[['src',`images/${primarylang.split(' ')[0]}.png`]]},lang_head)
+  let lang_body = newElement({element:'div',cls:['uk-card-body','uk-padding-small','uk-text-center']},lang_card).innerHTML = `${primarylang.split(' ')[1]}`
+  //let div_pl = document.createElement('div');
+  //div_pl.classList.add('col-md-3', 'col-sm-12', 'form-group')
+  //div_pl.innerHTML = `<a href="#" onclick="langSelected('${primarylang.split(' ')[0]}_${primarylang.split(' ')[0]}.UTF-8');"><img class="sprachwahl" src="images/${primarylang.split(' ')[0]}.png"> ${primarylang.split(' ')[1]}</a>`
+  //li_pl.setAttribute('style','float: none;width: 100%;margin-bottom: 10px;')
+  //li_pl.innerHTML = `<a style="justify-content: space-between;" href="#select" onclick="langSelected('${primarylang.split(' ')[0]}_${primarylang.split(' ')[0]}.UTF-8');"><img class="sprachwahl_klein" src="images/${primarylang.split(' ')[0]}.png">${primarylang.split(' ')[1]}</a>`
+  //lang_list.prepend(li_pl)
   // lang_list_2.prepend(div_pl)
   zusatzlang.forEach(langs => {
-  let div = document.createElement('div');
-  div.classList.add('col-md-3', 'col-sm-12', 'form-group')
-  div.innerHTML = `<a href="#" onclick="langSelected('${langs.split(' ')[0]}_${langs.split(' ')[0]}.UTF-8');"><img class="sprachwahl" src="images/${langs.split(' ')[0]}.png"> ${langs.split(' ')[1]}</a>`
-  let li = document.createElement('li');
-  li.setAttribute('style','float: none;width: 100%;margin-bottom: 10px;')
-  li.innerHTML = `<a style="justify-content: space-between;" href="#select" onclick="langSelected('${langs.split(' ')[0]}_${langs.split(' ')[0]}.UTF-8');"><img class="sprachwahl_klein" src="images/${langs.split(' ')[0]}.png">${langs.split(' ')[1]}</a>`
-  lang_list.append(li)
+  let lang_card = newElement({element:'div',cls:['uk-card','uk-card-default','cur_pointer','lang-card'],attr:[['onclick',`langSelected('${langs.split(' ')[0]}_${langs.split(' ')[0]}.UTF-8')`]]},lang_list)
+  let lang_head = newElement({element:'div',cls:['uk-card-header','flex-column-center']},lang_card)
+  let lang_img  = newElement({element:'img',cls:['sprachwahl'],attr:[['src',`images/${langs.split(' ')[0]}.png`]]},lang_head)
+  let lang_body = newElement({element:'div',cls:['uk-card-body','uk-padding-small','uk-text-center']},lang_card).innerHTML = `${langs.split(' ')[1]}`
+  //let div = document.createElement('div');
+  //div.classList.add('col-md-3', 'col-sm-12', 'form-group')
+  //div.innerHTML = `<a href="#" onclick="langSelected('${langs.split(' ')[0]}_${langs.split(' ')[0]}.UTF-8');"><img class="sprachwahl" src="images/${langs.split(' ')[0]}.png"> ${langs.split(' ')[1]}</a>`
+  //let li = document.createElement('li');
+  //li.setAttribute('style','float: none;width: 100%;margin-bottom: 10px;')
+  //li.innerHTML = `<a style="justify-content: space-between;" href="#select" onclick="langSelected('${langs.split(' ')[0]}_${langs.split(' ')[0]}.UTF-8');"><img class="sprachwahl_klein" src="images/${langs.split(' ')[0]}.png">${langs.split(' ')[1]}</a>`
+  //lang_list.append(li)
   // lang_list_2.append(div)
   });
+}
 /* The above code is used to change the placeholder of the input fields. */
   for(const key3 in document.querySelectorAll('[key-place]')){
     const element3 = document.querySelectorAll('[key-place]')[key3];
@@ -144,7 +263,7 @@ function langSelected(lang) {
   let result = lang.substring(0, 2);
   var url = `/production/setlanguagefile.tcls?systemsprache=${result}`;
   localStorage.setItem('lang',result)
-  fetch("/production/localisation/lang.json", {
+  fetch("/production/json/lang.json", {
     mode: "no-cors",
   }) // disable CORS because path does not contain http(s)
     .then((res) => res.json())
@@ -154,6 +273,11 @@ function langSelected(lang) {
   httplang.send();
 }
 
+/**
+ * The function `dashboardCards` fetches data from a JSON file, disables CORS, and then calls the
+ * `DashCards` function with the fetched data, followed by calling the `translatejs` function. If an
+ * error occurs, the `getError` function is called.
+ */
 function dashboardCards() {
   try {
     fetch("/production/json/cards.json", {
@@ -161,13 +285,44 @@ function dashboardCards() {
     }) // disable CORS because path does not contain http(s)
     .then((res) => res.json())
     .then((data) => (DashCards(data)));
+    translatejs()
   } catch (error) {
     getError(error)
   }
 }
 
-var cardsReady = false
+/* The above code is attempting to fetch data from a JSON file located at "/htdocs.json" using the
+Fetch API in JavaScript. The fetch request is set to "no-cors" mode, which means that the response
+will not be blocked by CORS (Cross-Origin Resource Sharing) restrictions. */
+  try {
+    fetch("/htdocs.json", {
+      mode: "no-cors",
+    })
+    .then((res)=> res.json())
+    .then((data)=>htdocs(data)) 
+  } catch (error) {
+    getError(error)
+  }
 
+/**
+ * The function htdocs takes a JSON object as input and updates the innerHTML of all elements with the
+ * class 'version' to the value of the VERSION property in the JSON object.
+ * @param jsn - The parameter `jsn` is expected to be a JSON object containing information about the
+ * `htdocs` version.
+ */
+function htdocs (jsn){
+  htdocsInfo = jsn
+  for (const ele of document.getElementsByClassName('version')) {
+    ele.innerHTML = htdocsInfo.VERSION
+  }
+}
+/**
+ * The DashCards function creates and appends HTML elements based on the provided JSON data to display
+ * dashboard cards.
+ * @param jsn - The `jsn` parameter is an object that contains the data for creating the dash cards. It
+ * should have a property called `dashbordcards` which is an array of objects representing each dash
+ * card. Each dash card object should have the following properties:
+ */
 function DashCards(jsn){
   const to = document.getElementById('dash-card-holder');
   for (const key in jsn) {
@@ -196,7 +351,7 @@ function DashCards(jsn){
  */
 function translatejs() {
   try {
-    fetch("/production/localisation/lang.json?v=1", {
+    fetch("/production/json/lang.json?v=1", {
       mode: "no-cors",
     }) // disable CORS because path does not contain http(s)
       .then((res) => res.json())
@@ -206,24 +361,22 @@ function translatejs() {
   }
 }
 
-$(document).ready(function () {
-  translatejs();
-  localstart();
-});
 
+
+/**
+ * The function reinit is used to reload the current page after removing an item from the localStorage
+ * and sending a GET request to a specific URL.
+ */
 function reinit() {
-  var url = "/production/reinit.tcls";
-
+  let url = "/production/reinit.tcls";
   localStorage.removeItem('smartcube')
-
   httpreboot.open("GET", url, true);
   httpreboot.send();
-
   let inter = setInterval(()=> {
     window.location.reload(true);
       clearInterval(inter);
     }, 1000);
-} // reinit()
+}
 /**
  * The function starts a countdown and then reboots the Velobox
  */
@@ -270,22 +423,37 @@ function countdown() {
  * @param {Arraya<string>}params - an array of strings that will be used to create the breadcrumb.
  */
 function BreadCrumb(params) {
-    var path = $('.meinpfad')[0];
+    let path = $('.meinpfad')[0];
     path.innerHTML = "";
-    var ihome = document.createElement('i');
+    let ihome = document.createElement('i');
     ihome.classList.add('mdi','mdi-sitemap')
-    var spanhome = document.createElement('span');
+    let spanhome = document.createElement('span');
     spanhome.setAttribute('key','mainmenu_home');
     spanhome.setAttribute('onclick',`LinkTo('dashboard.tcls')`)
     path.append(ihome);
     path.append(spanhome);
     params.forEach(element => {
-      var i = document.createElement('i');
+      let i = document.createElement('i');
       i.classList.add('mdi','mdi-menu-right');
       path.append(i);
-      var s = document.createElement('span');
+      let s = document.createElement('span');
       // s.classList.add('tr');
       s.setAttribute('key',`bread_${element}`)
+      if(location.pathname == "/production/clients.tcls"){
+        document.getElementsByClassName('headliner')[0].setAttribute('key',`bread_${element}`)
+      }
+      if(location.pathname == "/production/newclient.tcls"){
+        document.getElementsByClassName('headliner')[0].setAttribute('key',`bread_${element}`)
+      }
+      if(location.pathname == "/production/tpfs.tcls"){
+        document.getElementsByClassName('headliner')[0].setAttribute('key',`bread_${element}`)
+      }
+      if(location.pathname == "/production/galerie.tcls"){
+        document.getElementsByClassName('headliner')[0].setAttribute('key',`bread_${element}`)
+      }
+      if(location.pathname == "/production/system.tcls"){
+        document.getElementsByClassName('headliner')[0].setAttribute('key',`bread_${element}`)
+      }
       s.setAttribute('onclick',`LinkTo('${element}.tcls')`)
       s.setAttribute('style','cursor: pointer')
       s.innerHTML = element;
@@ -295,6 +463,7 @@ function BreadCrumb(params) {
         let a = document.createElement('a');
         a.classList.add('font-12');
         a.setAttribute('key',`bread_${element}`);
+        a.setAttribute('onclick',`LinkTo('${element}.tcls')`)
         a.setAttribute('href',`/production/${element}.tcls`)
         a.id = element.replaceAll(' ','')
         a.innerHTML = element
@@ -302,11 +471,11 @@ function BreadCrumb(params) {
         // li.classList.add('hidden')
         //}
         if(element==='client'){
-          let a2 = newElement({element:'a',attr:[['href',`/production/${element}.tcls`],['style','display:none;']]},li)
+          let a2 = newElement({element:'a',attr:[['onclick',`LinkTo('${element}.tcls')`],['style','display:none;']]},li)
           a.removeAttribute('key');
           a.innerHTML = localStorage.getItem('client_name')
-          a.setAttribute('href','#')
-          a.setAttribute('onclick',`info(${localStorage.getItem('client_id')},'${localStorage.getItem('client_name')}','${localStorage.getItem('client_mail')||""}','${localStorage.getItem('client_fc')}')`)
+          a.setAttribute('href',`/production/client.tcls`)
+          a.setAttribute('onclick',`info(${localStorage.getItem('client_id')},'${localStorage.getItem('client_name')}','${localStorage.getItem('client_forenames')}','${localStorage.getItem('client_surename')}','${localStorage.getItem('client_mail')||""}','${localStorage.getItem('client_fc')}')`)
           //info(`${localStorage.getItem('client_id')}`,`${localStorage.getItem('client_name')}`,`${localStorage.getItem('client_mail')||""}`,`${localStorage.getItem('client_fc')}`)
           s.removeAttribute('key');
           s.innerHTML = localStorage.getItem('client_name')
@@ -339,7 +508,9 @@ function HelpReset() {
  * @param params - The name of the parameter you want to pass to the function.
  */
 function LinkTo(params) {
+  console.log(params);
   location.href = `/production/${params}`
+  localStorage.setItem('force',false)
 }
 
 function mod_about() {
@@ -396,8 +567,8 @@ if(location.pathname == "/production/dashboard.tcls"){
 if(location.pathname == "/production/clients.tcls"){
   BreadCrumb(['dashboard','clients']);
 }
-if(location.pathname == "/production/session.tcls"){
-  BreadCrumb(['dashboard','clients','session']);
+if(location.pathname == "/production/newclient.tcls"){
+  BreadCrumb(['dashboard','clients','newclient']);
 }
 if(location.pathname == "/production/client.tcls"){
   BreadCrumb(['dashboard','clients','client'])
@@ -443,6 +614,10 @@ var checkbox_mask2 = document.getElementById('mask2')
 var checkbox_set_comp = document.getElementById('set_comp')
 var checkbox_maskedit = document.getElementById('maskedit');
 
+/**
+ * The function `chk_wifi()` checks the status of the Ethernet and WiFi connections and updates the
+ * corresponding elements on the webpage accordingly.
+ */
 function chk_wifi() {
 const btn_eth = document.getElementById('eth');
 const span_eth = document.getElementById('eth_con');
@@ -485,31 +660,10 @@ try {
 }
 }
 
-$(document).ready(function () {
-  chk_wifi();
-  ToggleViewMode(localStorage.getItem("viewmode"));
-  if(localStorage.getItem('viewmode')==='basic'){
-    checkbox_view.removeAttribute('checked');
-    // document.getElementById("basic").nextSibling.classList.remove('custom_switch')
-    ToggleViewMode('basic');
-  } else{
-    try {
-    checkbox_view.setAttribute('checked','')
-    // document.getElementById("basic").nextSibling.classList.add('custom_switch')
-    ToggleViewMode('advanced');
-  } catch (error) {
-    getError(error)
-    }
-  }
-  if(location.pathname == "/production/saddle_pressure_analysis.tcls"){
-    checkbox_mask1.removeAttribute('checked')
-    checkbox_mask2.removeAttribute('checked')
-    checkbox_maskedit.removeAttribute('checked')
-  }
-});
-
-
-
+/* The above code is adding an event listener to a checkbox element with the id "checkbox_view". When
+the checkbox is checked, it logs "basic is checked.." to the console and calls the function
+ToggleViewMode with the argument 'advanced'. When the checkbox is unchecked, it logs "basic is not
+checked.." to the console and calls the function ToggleViewMode with the argument 'basic'. */
 checkbox_view.addEventListener('change', function() {
 if (this.checked) {
   console.log("basic is checked..");
@@ -639,13 +793,17 @@ cw = $(window).width()/1.25;
 
 try {
 let side_smartcube = document.getElementById('sitzknochen-menu');
-  side_smartcube.setAttribute('href','/production/sitzknochenvermessung.tcls?check=true')
+  side_smartcube.setAttribute('href','/production/seat_bone.tcls?check=true')
 } catch (error) {
   getError(error)
 }
 
 
-/* A clock. */
+/* The above code is creating a clock that updates every second. It uses the setInterval function to
+execute a function every 1000 milliseconds (1 second). Inside the function, it gets the current time
+using the Date object. It then formats the time into hours, minutes, and seconds, adding leading
+zeros if necessary. Finally, it updates the innerHTML of an element with the id 'clock' with the
+formatted time. */
 let clock_dash = setInterval(function () {
   let c = document.getElementById('clock');
   let time = new Date();
@@ -734,7 +892,8 @@ function CreateReadMeMod(params) {
  * single "OK" button for the user to dismiss the dialog.
  */
 function getError (err){
-  OpenModDialog({type:'error',title:["error"],msg:`${err}`,master_btn:['button_ok']})
+  console.log('getError',err);
+  OpenModDialog({type:'error',title:["error"],msg:JSON.stringify(err),master_btn:['button_ok']})
 }
 
 /**
@@ -758,18 +917,27 @@ function showErrormessage() {
   }
   }
 }
+
+
 /**
- * `window.open(url, name, specs, replace)`
- *
- * The `url` is the page you want to open. The `name` is the name of the window. The `specs` are the
- * features of the window. The `replace` is a boolean value that determines whether the URL creates a
- * new entry or replaces the current entry in the history list
+ * The openWindow function redirects the user to the dashboard page.
  */
 function openWindow() {
+  location.pathname = 'production/dashboard.tcls'
+}
+
+/**
+ * The function opens a new window with a specific URL and dimensions, and then closes the current
+ * window.
+ */
+function openNewWindow() {
   window.open(`${location.origin}/production/dashboard.tcls`, "NewWindow",`toolbar=no,menubar=no,scrollbars=no,fullscreen=yes,width=${screen.width},height=${screen.height}`)
-  //this.close()
   closeWindow()
 }
+
+/**
+ * The closeWindow function opens a new window and then closes the current window.
+ */
 function closeWindow() {
   window.open('','_parent','');
   window.close();
@@ -850,6 +1018,9 @@ UIkit.modal(modal).show();
 var elem = document.documentElement;
 var fullScreen = false
 
+/**
+ * The function toggles between opening and closing fullscreen mode.
+ */
 function Vollbild() {
     if (fullScreen) {
         closeFullscreen()
@@ -859,6 +1030,9 @@ function Vollbild() {
         }
     }
 
+/**
+ * The function opens the browser in fullscreen mode if supported by the browser.
+ */
 function openFullscreen() {
     if (elem.requestFullscreen) {
         elem.requestFullscreen();
@@ -875,6 +1049,9 @@ function openFullscreen() {
         fullScreen = true
     }
 
+/**
+ * The closeFullscreen function is used to exit fullscreen mode in a web browser.
+ */
 function closeFullscreen() {
     if (document.exitFullscreen) {
         document.exitFullscreen();
@@ -891,3 +1068,155 @@ function closeFullscreen() {
         fullScreen=false
     }
 
+/**
+ * The function `setUserCompany` sets the value of `script_setting.UserCompany` to the provided
+ * parameter.
+ * @param params - The `params` parameter is a variable that represents the value you want to set for
+ * the `UserCompany` property in the `script_setting` object.
+ */
+function setUserCompany(params){
+  script_setting.UserCompany = params
+}
+
+/**
+ * The function sets the value of the UserName property in the script_setting object.
+ * @param params - The `params` parameter is a variable that represents the value you want to set as
+ * the username.
+ */
+function setUserName(params){
+  script_setting.UserName = params
+}
+
+/**
+ * The function `setUserCity` sets the user's city in a script setting.
+ * @param params - The `params` parameter is a variable that represents the value you want to set for
+ * the `UserCity` property in the `script_setting` object.
+ */
+function setUserCity(params){
+  script_setting.UserCity = params
+}
+
+/**
+ * The function `setUserStreet` sets the value of `script_setting.UserStreet` to the provided
+ * parameter.
+ * @param params - The `params` parameter is a variable that represents the value of the user's street
+ * address.
+ */
+function setUserStreet(params){
+  script_setting.UserStreet = params
+}
+
+/**
+ * The function `setUserMail` sets the value of `script_setting.UserMail` to the provided parameter.
+ * @param params - The `params` parameter is the email address that you want to set for the user.
+ */
+function setUserMail(params){
+  script_setting.UserMail = params
+}
+
+/**
+ * The function `setUserWeb` sets the value of `script_setting.UserWeb` to the provided parameter.
+ * @param params - The `params` parameter is a variable that represents the value you want to set for
+ * the `UserWeb` property in the `script_setting` object.
+ */
+function setUserWeb(params){
+  script_setting.UserWeb = params
+}
+
+/**
+ * The function `setUserPhone` sets the value of `script_setting.UserPhone` to the provided parameter.
+ * @param params - The `params` parameter is the value that will be assigned to the `UserPhone`
+ * property of the `script_setting` object.
+ */
+function setUserPhone(params){
+  script_setting.UserPhone = params
+}
+
+/**
+ * The function `setUserUnit` sets the `UserUnit` property of the `script_setting` object to the
+ * provided parameter.
+ * @param params - The `params` parameter is the value that will be assigned to the `UserUnit` property
+ * of the `script_setting` object.
+ */
+function setUserUnit(params){
+  script_setting.UserUnit = params
+}
+
+/**
+ * The function setUserEinleitung sets the UserEinleitung property in the script_setting object to the
+ * provided parameter.
+ * @param params - The `params` parameter is a variable that can hold any value. It is used as an
+ * argument when calling the `setUserEinleitung` function. The purpose of this function is to set the
+ * value of the `UserEinleitung` property in the `script_setting` object.
+ */
+function setUserEinleitung(params){
+  script_setting.UserEinleitung = params
+}
+
+/**
+ * The function `saveConfig` sends the client settings as a JSON string over a WebSocket connection.
+ */
+function saveConfig(){
+  script_websocket.send(`set clientsettings ${JSON.stringify(script_setting)}`)
+}
+
+$(document).ready(function () {
+  translatejs();
+  localstart();
+  chk_wifi();
+  ToggleViewMode(localStorage.getItem("viewmode"));
+  if(localStorage.getItem('viewmode')==='basic'){
+    checkbox_view.removeAttribute('checked');
+    // document.getElementById("basic").nextSibling.classList.remove('custom_switch')
+    ToggleViewMode('basic');
+  } else{
+    try {
+    checkbox_view.setAttribute('checked','')
+    // document.getElementById("basic").nextSibling.classList.add('custom_switch')
+    ToggleViewMode('advanced');
+  } catch (error) {
+    getError(error)
+    }
+  }
+  if(location.pathname == "/production/saddle_pressure_analysis.tcls"){
+    checkbox_mask1.removeAttribute('checked')
+    checkbox_mask2.removeAttribute('checked')
+    checkbox_maskedit.removeAttribute('checked')
+  }
+});
+
+//const input = document.querySelector("input");
+
+const input = document.getElementsByTagName('input')
+
+for (const i of input) {
+  i.addEventListener("input",updateValue)
+}
+
+/**
+ * The function `updateValue` is used to update the value of an input element and display a warning
+ * notification if the value contains either a double quote or a single quote.
+ * @param e - The parameter `e` is an event object that is passed to the function when it is called as
+ * an event handler. It represents the event that triggered the function, such as a keypress or a
+ * change in an input field.
+ */
+function updateValue(e) {
+  const color = "var(--light-4)"
+  let txt = this.value
+  let ele = this
+
+  if(typeof this.value === "undefined"){
+    txt = e.value
+    ele = e
+  }
+
+  if(txt.includes('"')){
+    ele.value = ele.value.replaceAll('"','')
+    UIkit.notification({message: `" ${aLangKeys[lang].not_allowed}`, status: 'warn'})
+  }
+
+  if(txt.includes("'")){
+    ele.value = ele.value.replaceAll("'",'')
+    UIkit.notification({message: `' ${aLangKeys[lang].not_allowed}`, status: 'warn'})
+  }
+}
\ No newline at end of file
