@@ -79,6 +79,7 @@ analysis.x1 = new Object();
 sitzknochen.onopen = (e)=>{
 //  sitzknochen.send(`session restart ${sessionID}`)
 //  sitzknochen.send(`analysis ["sitbones","anamnesis","x1"]`)
+sendMatte('switch create_norm on')
 }
 
 sitzknochen.onmessage = (e) => {
@@ -88,34 +89,28 @@ sitzknochen.onmessage = (e) => {
 
   if(data.change === 'unplugged'){
     sitzknochen_activ=false;
-    Matte.classList.toggle('nor')
-    Matte.classList.toggle('err')
+    Matte.classList.remove('nor')
+    Matte.classList.add('err')
     OpenModDialog({type:'warn',title:["sk_hocker"],msg:["sk_hocker_dis"],master_btn:['button_ok','location.reload()']})
     
   }
   if(data.change === "plugged"){
     sitzknochen_activ=true;
-    if(Matte.classList.contains('err')){
-      Matte.classList.toggle('nor')
-      Matte.classList.toggle('err')
-    }
-    OpenModDialog({type:'neutral',title:["sk_hocker"],msg:["sk_hocker_con"],master_btn:['button_ok']})
+      Matte.classList.remove('nor')
+      Matte.classList.add('err')
+    //OpenModDialog({type:'neutral',title:["sk_hocker"],msg:["sk_hocker_con"],master_btn:['button_ok']})
   }
   
   if(data.wsevent ==="ttystate"){
         if(data.state === "inactive"){
             sitzknochen_activ=false;
-            if(Matte.classList.contains('err')){
-              Matte.classList.toggle('nor')
-              Matte.classList.toggle('err')
-            }
+              Matte.classList.remove('nor')
+              Matte.classList.add('err')
         } else if(data.state === "active"){
-          if(Matte.classList.contains('err')){
-            Matte.classList.toggle('nor')
-            Matte.classList.toggle('err')
-          }
+            Matte.classList.add('nor')
+            Matte.classList.remove('err')
             sitzknochen_activ=true;
-            OpenModDialog({type:'neutral',title:["sk_hocker"],msg:["sk_hocker_con"],master_btn:['button_ok']})
+            //OpenModDialog({type:'neutral',title:["sk_hocker"],msg:["sk_hocker_con"],master_btn:['button_ok']})
         }
   }
   if(data.wsevent === 'hockerbild'&&sitzknochen_activ===true){
@@ -324,8 +319,8 @@ sitzknochen.onmessage = (e) => {
 }
 
 ws_ska.onerror = () =>{
-  SmartCube.classList.toggle('err')
-  SmartCube.classList.toggle('nor')
+  SmartCube.classList.add('err')
+  SmartCube.classList.remove('nor')
 }
 
 ws_ska.onmessage = (e) =>{
@@ -339,7 +334,9 @@ ws_ska.onmessage = (e) =>{
     }
     
     if(data.wsevent == 'plugged'){
-    OpenModDialog({type:'neutral',title:["con_connected"],msg:['con_connected_msg'],master_btn:['button_ok']})
+    //OpenModDialog({type:'neutral',title:["con_connected"],msg:['con_connected_msg'],master_btn:['button_ok']})
+    SmartCube.classList.add('nor');
+    SmartCube.classList.remove('err');
     //document.getElementById('con_ws').innerHTML = aLangKeys[lang][]
         //OpenMod('connected')
         //document.getElementById('glow').classList.add('glow')
@@ -354,7 +351,7 @@ ws_ska.onmessage = (e) =>{
     if(data.wsevent === 'sitzknochenabstand' && vsum === 0 && sitzknochen_activ===false){
       //if(vsum == 0){
         vsum = 1
-        store(data.sitzknochenabstand,"sitzknochenabstand","sitbones")
+        //store(data.sitzknochenabstand,"sitzknochenabstand","sitbones")
         document.getElementById('val').value = data.sitzknochenabstand
         var inter = setInterval( () => {
           draw_cross(canvas_ska,[(data.schwerpunkt1_x+0.5) * (cw / 28) , (cw/1.75) - (data.schwerpunkt1_y+0.5) * (cw / 28)]);
@@ -364,7 +361,7 @@ ws_ska.onmessage = (e) =>{
           document.getElementById('val').value = `${cm}` //<br> ${inch}`
           document.getElementById('sitzknochenabstand').value = data.sitzknochenabstand
             userdata['sitzknochenabstand'] = data.sitzknochenabstand
-            SendSkImg();
+            //SendSkImg();
         //  changeEventHandler(document.getElementById('sitzknochenabstand').value)
             progress(1)
           localStorage.setItem('sk',`${cm}`)
@@ -376,10 +373,27 @@ ws_ska.onmessage = (e) =>{
     }
 }
 
+/**
+ * The lineDistance function calculates the distance between two points in a two-dimensional space.
+ * @param p1 - The parameter `p1` represents the coordinates of the first point on the line. It is an
+ * array with two elements, where the first element is the x-coordinate and the second element is the
+ * y-coordinate.
+ * @param p2 - The parameter `p2` represents the coordinates of the second point in the line. It is an
+ * array with two elements, where the first element is the x-coordinate and the second element is the
+ * y-coordinate.
+ * @returns the distance between two points, `p1` and `p2`.
+ */
 function lineDistance(p1, p2) {
   return Math.hypot(p2[0] - p1[0], p2[1] - p1[1])
 }
 
+/**
+ * The function `draw_cross` draws a cross shape on a canvas element at a specified position.
+ * @param ele - The parameter "ele" represents the HTML canvas element on which the cross will be
+ * drawn. It is of type "CanvasRenderingContext2D".
+ * @param pos - The `pos` parameter represents the position of the cross on the canvas. It is an array
+ * containing the x and y coordinates of the cross's center point.
+ */
 function draw_cross(ele,pos) {
   console.log(pos);
   let c = ele.getContext('2d')
@@ -584,7 +598,7 @@ function AXIOS_AutoLogin() {
             .then(response => {
                 if (response.data === '12 forbidden') {
                     sessionStorage.setItem('error', JSON.stringify(response));
-                    change_site('error');
+                    OpenModDialog({type:'error',title:["error"],msg:`${response.data}`,master_btn:['button_ok']})
                     return;
                 }
                     AXIOS_Load_Produckte();
@@ -592,7 +606,7 @@ function AXIOS_AutoLogin() {
             .catch(err => {
                 console.error(err);
                 sessionStorage.setItem('error', err);
-                change_site('error');
+                OpenModDialog({type:'error',title:["error"],msg:`${err}`,master_btn:['button_ok']})
             });
 }
 
@@ -655,7 +669,7 @@ function create_block(jsn) {
     let headD   = newElement({element:"div",cls:["uk-grid-small", "uk-flex-middle"],attr:[['uk-grid','']]},head)
     if(jsn.code == 'sattelextras'||jsn.code == 'probleme'){
         headT   = newElement({element:"h6",cls:['isLink'],attr:[['key',`tpfs_${jsn.code}`],['onclick',`toggleHidden('${jsn.code}')`]]},headD).innerHTML = `${aLangKeys[lang]['tpfs_${jsn.code}']}`
-        newElement({element:'span',cls:['mdi','mdi-24px','mdi-chevron-down'],attr:[['style','color:var(--primary)']]},headD) //mdi-chevron-right
+        newElement({element:'span',cls:['isLink','mdi','mdi-24px','mdi-chevron-down'],attr:[['style','color:var(--primary)'],['onclick',`toggleHidden('${jsn.code}')`]]},headD) //mdi-chevron-right
         newElement({element:'hr'},block)
         content = newElement({element:"div",id:`hidden_${jsn.code}`,cls:['uk-card-body','uk-hidden']},block)
 
@@ -698,7 +712,7 @@ function genSelect(jsn,to,name,pflicht) {
                 progressMax(Object.keys(isrequired).length+1)
                 if(e.code != null){
                     newElement({element:'input',id:`${name}_${e.code}`,cls:['question_input'],attr:[['type','radio'],['name',`${name}`],['value',`${e.code}`],['required','true'],['data-progress','1'],['onclick','changeEventHandler(event)']]},card)
-                    newElement({element:'label',cls:['question_label'],attr:[['for',`${name}_${e.code}`],['style',`background-image: url(/production/images/svg/${name}_${e.code}.png)`]]},card)
+                    newElement({element:'label',cls:['question_label'],attr:[['key-title',`title_${name}${e.code}`],['for',`${name}_${e.code}`],['style',`background-image: url(/production/images/svg/${name}_${e.code}.png)`]]},card)
                     //newElement({element:"input",attr:[["style",`background: url(/production/images/svg/${name}_${e.code}.png)`],['data-value',`${e.code}`],['data-name',`${name}`],['type','radio']]},head)
                 }
             } else {
@@ -706,9 +720,9 @@ function genSelect(jsn,to,name,pflicht) {
                 if(e.code != null){
                     newElement({element:'input',id:`${name}_${e.code}`,cls:['question_input'],attr:[['type','radio'],['name',`${name}`],['value',`${e.code}`],['onclick','changeEventHandler(event)']]},card)
                     if(e.code == 'ja'||e.code == 'nein'||e.code == 'egal'){
-                        newElement({element:'label',cls:['question_label'],attr:[['for',`${name}_${e.code}`],['style',`background-image: url(/production/images/svg/${e.code}.png)`]]},card)
+                        newElement({element:'label',cls:['question_label'],attr:[['key-title',`title_${name}${e.code}`],['for',`${name}_${e.code}`],['style',`background-image: url(/production/images/svg/${e.code}.png)`]]},card)
                     } else {
-                        newElement({element:'label',cls:['question_label'],attr:[['for',`${name}_${e.code}`],['style',`background-image: url(/production/images/svg/${name}_${e.code}.png)`]]},card)
+                        newElement({element:'label',cls:['question_label'],attr:[['key-title',`title_${name}${e.code}`],['for',`${name}_${e.code}`],['style',`background-image: url(/production/images/svg/${name}_${e.code}.png)`]]},card)
                     }
                     //newElement({element:"input",attr:[["style",`background: url(/production/images/svg/${name}_${e.code}.png)`],['data-value',`${e.code}`],['data-name',`${name}`],['type','radio']]},head)
                 }
