@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-# velobox_update_3.0.4
+# velobox_update_3.0.5
 # Einspielen aller Dateien in /usr/local/vmkstationd3/
 # Velometrik-GmbH
 # Breunsdorfer Str. 48a
@@ -10,37 +10,44 @@
 # support@velometrik.de
 #
 # Historie:
-# 12.06.2023	Björn Bauer	erstellt
+# 16.10.2023	Peter Bauer	erstellt
 
-LAST_VERSION=3.0.3
-CURRENT_VERSION=3.0.4
+LAST_VERSION=3.0.4
+CURRENT_VERSION=3.0.5
 
 if [ `whoami` != "root" ]; then
 echo "ERROR"
-	echo "The script must be executed by root!"
-	exit 1
+    echo "The script must be executed by root!"
+    exit 1
 fi
 
 if [ `awk -F '=' '/VERSION/ {print $2}' /usr/local/etc/velobox.conf` != $LAST_VERSION ]; then
 echo "ERROR"
-	echo "Please install update velobox_update_$LAST_VERSION.tar.gz first!"
-	exit 1
+echo "You need the Update $LAST_VERSION first!"
+exit 1
+fi
+
+echo "htdocs leeren"
+rm -r /usr/local/vmkstationd/htdocs/
+if [ $? -ne 0 ]; then
+echo "ERROR"
+    echo "The folder "htdocs" could not be deleted!"
+    exit 1
 fi
 
 echo "Files in / will be installed."
 if [ ! -r velobox_update_$CURRENT_VERSION.tar.gz ]; then
 echo "ERROR"
-	echo "velobox_update_$CURRENT_VERSION.tar.gz not found" 
-	exit 1
+    echo "velobox_update_$CURRENT_VERSION.tar.gz not found" 
+    exit 1
 fi
 
 cp velobox_update_$CURRENT_VERSION.tar.gz /
 if [ $? -ne 0 ]; then
 echo "ERROR"
-	echo "Can't copy velobox_update_$CURRENT_VERSION.tar.gz to / ."
-	exit 1
+    echo "Can't copy velobox_update_$CURRENT_VERSION.tar.gz to / ."
+    exit 1
 fi
-
 cd /
 test $? -ne 0 && exit 1
 tar xf velobox_update_$CURRENT_VERSION.tar.gz
@@ -48,47 +55,21 @@ test $? -ne 0 && exit 1
 rm -f velobox_update_$CURRENT_VERSION.tar.gz
 
 echo "Files in / were recorded."
-        
-echo "Delete current symbolic link to vmkstationd"
-rm /usr/local/vmkstationd
-if [ $? -ne 0 ]; then
-echo "ERROR"
-    echo "error at # rm /usr/local/vmkstationd"
-    exit 1
-fi
-echo "done"
 
-echo "Create symbolic link to vmkstationd"
-ln -s /usr/local/vmkstationd3.1.0_U/ /usr/local/vmkstationd
-if [ $? -ne 0 ]; then
-echo "ERROR"
-    echo "error at # ln -s /usr/local/vmkstationd3.1.0_U/ /usr/local/vmkstationd"
-    exit 1
-fi
-echo "done"        
-
-echo "Delete vmkstationd3"
-rm -r /usr/local/vmkstationd3/
-if [ $? -ne 0 ]; then
-echo "ERROR"
-	echo "The folder "/usr/local/vmkstationd3/" could not be deleted!"
-	exit 1
-fi      
-        
 ### Do not change anything from here on! ###
 
-#################################
-### Write the current version ###
-echo "Set current version to $CURRENT_VERSION"
+###############################
+### aktuelle Version setzen ###
+echo "Set current version"
 sed -i s/VERSION=$LAST_VERSION/VERSION=$CURRENT_VERSION/g /usr/local/etc/velobox.conf
 if [ $? -ne 0 ]; then
 echo "ERROR"
-    echo "Can't set current version to $CURRENT_VERSION"
+    echo "Can't set current version"
     exit 1
 fi
 
-#########################
-### Adapt user rights ###
+###################################
+### Ab hier nichts mehr ändern! ###
 echo "Correct user rights in htdocs"
 chown -R root:root /usr/local
 if [ $? -ne 0 ]; then
